# LLGEO
### A Python Library for Geotechnical Engineering Applications

This is a test version!


version 0.0.3
- llgeo/quad4m/genfiles.py : added genfiles.py, which generates input files for QUAD4M. Note that KSAV and KOUT flags were not coded in so far, and will need to be added in later.
- llgeo/quad4m/geometry.py : fixed orientation of nodes (was clockwise instead of counter-clockwise)